@@ -3,6 +3,7 @@
 from enum import Enum
 
 COMMAND_OPTIONS = "options"
+COMMAND_HEARTBEAT = "heartbeat"
 COMMAND_QUEUE_INFO = "queue-info"
 COMMAND_SLOT_INFO = "slot-info"
 COMMAND_REQUEST_WORKSERVER_ASSIGNMENT = "request-ws"
@@ -10,7 +11,12 @@ COMMAND_PAUSE = "pause"
 COMMAND_UNPAUSE = "unpause"
 COMMAND_SHUTDOWN = "shutdown"
 
-SUBSCRIBE_COMMANDS = [COMMAND_OPTIONS, COMMAND_QUEUE_INFO, COMMAND_SLOT_INFO]
+SUBSCRIBE_COMMANDS = [
+    COMMAND_HEARTBEAT,
+    COMMAND_OPTIONS,
+    COMMAND_QUEUE_INFO,
+    COMMAND_SLOT_INFO,
+]
 UNSUBSCRIBE_ALL_COMMAND = "updates clear"
 
 PY_ON_MESSAGE_HEADER = "PyON 1"
